@@ -14,7 +14,7 @@ ShojiObject <- setClass("ShojiObject",
         views="ANY",
         fragments="ANY"
     ))
-
+ShojiEntity <- setClass("ShojiEntity", contains="ShojiObject")
 ShojiCatalog <- setClass("ShojiCatalog", contains="ShojiObject",
     representation(
         index="list",
@@ -307,3 +307,5 @@ DatasetGroup <- setClass("DatasetGroup", contains="OrderGroup",
         entities=list(),
         duplicates=FALSE
     ))
+
+setClass("Session", contains="list")
