@@ -99,7 +99,6 @@ crtabs <- function (formula, data, weight=crunch::weight(data),
     names(query$measures) <- vapply(query$measures, function (m) {
         sub("^cube_", "", m[["function"]])
     }, character(1))
-
     ## Get filter
     f <- zcl(activeFilter(data))
 
@@ -110,26 +109,27 @@ crtabs <- function (formula, data, weight=crunch::weight(data),
     )
 
     ## Go GET it!
-    cube_url <- shojiURL(data, "views", "cube")
-    return(CrunchCube(crGET(cube_url, query=query),
+    return(CrunchCube(crGET(cubeURL(data), query=query),
         useNA=match.arg(useNA)))
 }
 
-registerCubeFunctions <- function (varnames) {
+registerCubeFunctions <- function (varnames=c()) {
     ## Return a list of "cube functions" to substitute()
     ## in. A better approach, which would avoid potential name collisions, would
     ## probably be to have vars be an environment inside of another environment
     ## that has the cube functions. This version just checks for name collisions
     ## and errors if there is one.
 
-    numfunc <- function (func) {
+    numfunc <- function (func, ...) {
         force(func)
+        moreArgs <- list(...)
         return(function (x) {
             if (is.Categorical(x)) {
                 ## "Cast" it on the fly
-                x <- zfunc("cast", x, "numeric")
+                x <- list(zfunc("cast", x, "numeric"))
             }
-            zfunc(func, x)
+            do.call("zfunc", c(func, x, moreArgs))
+            # zfunc(func, x)
         })
     }
 
@@ -138,7 +138,16 @@ registerCubeFunctions <- function (varnames) {
         min=numfunc("cube_min"),
         max=numfunc("cube_max"),
         sd=numfunc("cube_stddev"),
-        sum=numfunc("cube_sum")
+        sum=numfunc("cube_sum"),
+        median=numfunc("cube_quantile", list(value=I(.5))),
+        as_array=function (x) {
+            ## Kinda hacky way to do a query of an MR as CA
+            if (!is.MR(x)) {
+                halt("Cannot analyze a variable of type ", dQuote(type(x)),
+                    " 'as_array'")
+            }
+            zfunc("as_array", x)
+        }
     )
 
     overlap <- intersect(varnames, names(funcs))
@@ -168,6 +177,11 @@ varsToCubeDimensions <- function (vars) {
             ## Put "each" first so that the rows, not columns, are subvars
             return(list(list(each=self(x)),
                 v))
+        } else if (is.list(x) && "function" %in% names(x) && x[["function"]] == "as_array") {
+            ## Pseudo-ZCL from registerCubeFunctions, used to treat an MR like a CA
+            ## x is thus list(`function`="as_array", args=list(list(variable=self)))
+            ## Return instead list(list(each=self), list(variable=self))
+            return(list(list(each=x$args[[1]]$variable), x$args[[1]]))
         } else {
             ## Just the var ref, but nest in a list so we can unlist below to
             ## flatten
