@@ -186,6 +186,11 @@ setMethod("activeFilter<-", "CrunchExpr", function (x, value) {
     return(x)
 })
 
+setMethod("activeFilter", "list", function (x) NULL)
+
+
+## See dataset-extract.R for .updateActiveFilter
+
 #' View and set exclusion filters
 #'
 #' Exclusion filters express logic that defines a set of rows that should be
