@@ -30,81 +30,71 @@ is.shoji.like <- function (x) {
     is.list(x) && "element" %in% names(x) && startsWith(as.character(x$element), "shoji")
 }
 
-##' @rdname crunch-is
-##' @export
-##' @importFrom methods is
+#' @rdname crunch-is
+#' @export
+#' @importFrom methods is
 is.shoji <- function (x) inherits(x, "shoji")
 
 is.shojiObject <- function (x) inherits(x, "ShojiObject")
 
-##' Get the URL of this object
-##' @param x a Crunch object
-##' @return the URL for \code{x}
-##' @aliases self
-##' @name self
+#' Get the URL of this object
+#' @param x a Crunch object
+#' @return the URL for \code{x}
+#' @aliases self
+#' @name self
 NULL
 
-##' @rdname self
-##' @export
+#' @rdname self
+#' @export
 setMethod("self", "ShojiObject", function (x) x@self)
 
-##' @rdname describe
-##' @export
+#' @rdname describe
+#' @export
 setMethod("name", "ShojiObject", function (x) x@body$name)
 
-##' @rdname refresh
-##' @export
+#' @rdname refresh
+#' @export
 setMethod("refresh", "ShojiObject", function (x) {
     dropCache(self(x))
     Class <- class(x)  ## in case x is a subclass of ShojiObject
     return(do.call(Class, crGET(self(x))))
 })
 
-##' @rdname delete
-##' @export
+#' @rdname delete
+#' @export
 setMethod("delete", "ShojiObject", function (x, ...) invisible(crDELETE(self(x))))
 
-##' @rdname delete
-##' @export
+#' @rdname delete
+#' @export
 setMethod("delete", "ANY", function (x, ...) halt("'delete' only valid for Crunch objects"))
 
-##' Base setter for Crunch objects
-##' @param x a ShojiObject or subclass thereof
-##' @param i character the slot name to update
-##' @param value whatever the new value of that slot should be
-##' @return x modified accordingly. If \code{x} isn't read-only, it will also
-##' post the edit to the Crunch server.
-##' @keywords internal
+#' Base setter for Crunch objects
+#' @param x a ShojiObject or subclass thereof
+#' @param i character the slot name to update
+#' @param value whatever the new value of that slot should be
+#' @return x modified accordingly. If \code{x} isn't read-only, it will also
+#' post the edit to the Crunch server.
+#' @keywords internal
 setEntitySlot <- function (x, i, value) {
     ## Check if we have actual changes to send. Wrap both sides in I()
     ## in case "value" is already wrapped
     if (!identical(I(slot(x, "body")[[i]]), I(value))) {
         slot(x, "body")[[i]] <- value
-        if (!is.readonly(x)) {
-            body <- structure(list(value), .Names=i)
-            payload <- toJSON(body)
-            crPATCH(self(x), body=payload)
-        }
+        body <- structure(list(value), .Names=i)
+        payload <- toJSON(body)
+        crPATCH(self(x), body=payload)
     }
     return(x)
 }
 
-is.readonly <- function (x) isTRUE(x@readonly) && !is.null(self(x))
-setReadonly <- function (x, value) {
-    x@readonly <- as.logical(value)
-    x
-}
-
-setMethod("readonly<-", "ShojiObject", setReadonly)
-
-##' Get a resource URL from a Shoji Object
-##' @param x a shojiObject
-##' @param collection one of c("catalogs", "views", "fragments")
-##' @param key character name of the URL to get from \code{collection}
-##' @return character URL
-##' @export
-##' @keywords internal
-##' @importFrom httpcache logMessage
+#' Get a resource URL from a Shoji Object
+#' @param x a shojiObject
+#' @param collection one of c("catalogs", "views", "fragments")
+#' @param key character name of the URL to get from \code{collection}
+#' @return character URL
+#' @export
+#' @keywords internal
+#' @importFrom httpcache logMessage
 shojiURL <- function (x, collection=c("catalogs", "views", "fragments", "orders"), key) {
     if (is.variable(x) || inherits(x, "ShojiTuple")) {
         x <- entity(x) ## Get the *Entity (e.g. VariableEntity)
