@@ -7,7 +7,7 @@ options(width=120)
 #  ordering(ds)
 
 ## ---- echo=FALSE------------------------------------------------------------------------------------------------------
-step0
+cat(step0.print, sep="\n")
 
 ## ---- eval=FALSE------------------------------------------------------------------------------------------------------
 #  ordering(ds) <- VariableOrder(
@@ -20,7 +20,7 @@ step0
 #  ordering(ds)
 
 ## ---- echo=FALSE------------------------------------------------------------------------------------------------------
-step1
+cat(step1.print, sep="\n")
 
 ## ---- eval=FALSE------------------------------------------------------------------------------------------------------
 #  names(ordering(ds))
@@ -47,5 +47,5 @@ names(step3)
 #  ordering(ds)
 
 ## ---- echo=FALSE------------------------------------------------------------------------------------------------------
-step4
+cat(step4.print, sep="\n")
 
