@@ -51,11 +51,11 @@ with_mock_HTTP({
 
     test_that("Variable setter requests", {
         expect_PATCH(name(ds$gender) <- "Sex",
-            "/api/datasets/dataset1/variables/",
-            '{"/api/datasets/dataset1/variables/gender/":{"name":"Sex"}}')
+            "/api/datasets/1/variables/",
+            '{"/api/datasets/1/variables/gender/":{"name":"Sex"}}')
         expect_PATCH(notes(ds$gender) <- "extra info",
-            "/api/datasets/dataset1/variables/",
-            '{"/api/datasets/dataset1/variables/gender/":{"notes":"extra info"}}')
+            "/api/datasets/1/variables/",
+            '{"/api/datasets/1/variables/gender/":{"notes":"extra info"}}')
     })
 
     test_that("Variable setters don't hit server if data not changed", {
